@@ -134,13 +134,13 @@ void init_config(ConfigCollection* collection) {
 	CmdLineOption* option;
 	CmdLineArgString* strarg;
 	CmdLineArgSet* setarg;
-/* GLE */
+	/* GLE */
 	section = new ConfigSection("gle");
 	strarg = section->addStringOption("current", GLE_CONFIG_GLE_VERSION);
 	strarg->setDefault("");
 	section->addSPairListOption("versions", GLE_CONFIG_GLE_INSTALL);
 	collection->addSection(section, GLE_CONFIG_GLE);
-/* Tools */
+	/* Tools */
 	section = new ConfigSection("tools");
 	/* LaTeX */
 	strarg = section->addStringOption("latex", GLE_TOOL_LATEX_CMD);
@@ -153,7 +153,7 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("vlatexp.cmd");
 #endif
-	section->addStringOption("latex_options", GLE_TOOL_LATEX_OPTIONS);
+	//section->addStringOption("latex_options", GLE_TOOL_LATEX_OPTIONS);
 
 	/* PdfLaTeX */
 	strarg = section->addStringOption("pdflatex", GLE_TOOL_PDFTEX_CMD);
@@ -162,7 +162,7 @@ void init_config(ConfigCollection* collection) {
 #else
 	strarg->setDefault("pdflatex");
 #endif
-	section->addStringOption("pdflatex_options", GLE_TOOL_PDFTEX_OPTIONS);
+	//section->addStringOption("pdflatex_options", GLE_TOOL_PDFTEX_OPTIONS);
 
 	/* DVIPS */
 	strarg = section->addStringOption("dvips", GLE_TOOL_DVIPS_CMD);
@@ -175,32 +175,15 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("dvips.exe");
 #endif
-	section->addStringOption("dvips_options", GLE_TOOL_DVIPS_OPTIONS);
+	//section->addStringOption("dvips_options", GLE_TOOL_DVIPS_OPTIONS);
+
 	/* GhostScript Program */
 	strarg = section->addStringOption("ghostscript", GLE_TOOL_GHOSTSCRIPT_CMD);
 #ifdef _WIN32
-	#define ENVIRONMENT32
-	#if _WIN32 || _WIN64
-		// Visual Studio builds with cl.exe
-		#if _WIN64
-			#define ENVIRONMENT64
-		#else
-			#define ENVIRONMENT32
-		#endif
-	#endif
-	#if __GNUC__
-		// gcc builds
-		#if __x86_64__ || __ppc64__
-			#define ENVIRONMENT64
-		#else
-			#define ENVIRONMENT32
-		#endif
-	#endif
-	#ifdef ENVIRONMENT32
-		strarg->setDefault("gswin32c.exe");
-	#endif
-	#ifdef ENVIRONMENT64
+	#if defined(_WIN64) || defined(__x86_64__)
 		strarg->setDefault("gswin64c.exe");
+	#else
+		strarg->setDefault("gswin32c.exe");
 	#endif
 #endif
 #ifdef __APPLE__
@@ -212,45 +195,28 @@ void init_config(ConfigCollection* collection) {
 #ifdef __OS2__
 	strarg->setDefault("gsos2.exe");
 #endif
-	section->addStringOption("ghostscript_options", GLE_TOOL_GHOSTSCRIPT_OPTIONS);
+	//section->addStringOption("ghostscript_options", GLE_TOOL_GHOSTSCRIPT_OPTIONS);
 
 	collection->addSection(section, GLE_CONFIG_TOOLS);
 	/* GhostScript Library */
 	strarg = section->addStringOption("libgs", GLE_TOOL_GHOSTSCRIPT_LIB);
 #ifdef _WIN32
-	#define ENVIRONMENT32
-	#if _WIN32 || _WIN64
-		// Visual Studio builds with cl.exe
-		#if _WIN64
-			#define ENVIRONMENT64
-		#else
-			#define ENVIRONMENT32
-		#endif
-	#endif
-	#if __GNUC__
-		// gcc builds
-		#if __x86_64__ || __ppc64__
-			#define ENVIRONMENT64
-		#else
-			#define ENVIRONMENT32
-		#endif
-	#endif
-	#ifdef ENVIRONMENT32
-		strarg->setDefault("gsdll32.dll");
-	#endif
-	#ifdef ENVIRONMENT64
+	#if defined(_WIN64) || defined(__x86_64__)
 		strarg->setDefault("gsdll64.dll");
+	#else
+		strarg->setDefault("gsdll32.dll");
 	#endif
 #endif
 #ifdef __APPLE__
-	strarg->setDefault("/Library/Frameworks/Ghostscript.framework,Ghostscript.framework");
+	strarg->setDefault("libgs.dylib");
+	//strarg->setDefault("/Library/Frameworks/Ghostscript.framework,Ghostscript.framework");
 #endif
 #if defined(__unix__) && !defined(__APPLE__)
-	strarg->setDefault("/usr/lib/libgs.so");
+	strarg->setDefault("libgs.so");
 #endif
 	strarg = section->addStringOption("editor", GLE_TOOL_TEXT_EDITOR);
 	strarg = section->addStringOption("pdfviewer", GLE_TOOL_PDF_VIEWER);
-/* TeX config */
+	/* TeX config */
 	section = new ConfigSection("tex");
 	option = new CmdLineOption("system");
 	setarg = new CmdLineArgSet("device-names");
@@ -265,7 +231,7 @@ void init_config(ConfigCollection* collection) {
 	option->addArg(setarg);
 	section->addOption(option, GLE_TEX_SYSTEM);
 	collection->addSection(section, GLE_CONFIG_TEX);
-/* Config paper */
+	/* Config paper */
 	section = new ConfigSection("paper");
 	strarg = section->addStringOption("size", GLE_CONFIG_PAPER_SIZE);
 	strarg->setDefault("a4paper");
@@ -408,6 +374,9 @@ void do_wait_for_enter_exit(int exitcode) {
 }
 
 class GLEProgressIndicatorInterface : public GLEProgressIndicator {
+private:
+	std::string m_chars;
+	size_t m_count;
 protected:
 	GLEInterface* m_Iface;
 public:
@@ -418,6 +387,8 @@ public:
 
 GLEProgressIndicatorInterface::GLEProgressIndicatorInterface(GLEInterface* iface) {
 	m_Iface = iface;
+	m_chars = "|/-\\";
+	m_count = 0;
 }
 
 GLEProgressIndicatorInterface::~GLEProgressIndicatorInterface() {
@@ -425,6 +396,10 @@ GLEProgressIndicatorInterface::~GLEProgressIndicatorInterface() {
 
 void GLEProgressIndicatorInterface::indicate() {
 	m_Iface->getOutput()->printflush(".");
+	//m_Iface->getOutput()->printflush(&m_chars[m_count]);
+	//m_Iface->getOutput()->printflush("\b");
+	//m_count++;
+	//if(m_count >= m_chars.length()){m_count=0;}
 }
 
 string get_tool_path(int tool, ConfigSection* tools) {
@@ -461,6 +436,7 @@ void find_deps(const string& loc, GLEInterface* iface) {
 		tokenizer<char_separator> tokens(strarg->getDefault(), separator);
 		while (tokens.has_more()) {
 			const string& toolName = tokens.next_token();
+			//cout <<"toolname: "<<toolName<<endl;
 			if (toolName == ";") {
 				if (tokens.has_more() && strarg->isDefault()) {
 					findTool->setNotFound(tokens.next_token());
@@ -518,14 +494,36 @@ void find_deps(const string& loc, GLEInterface* iface) {
 	for (unsigned int i = 0; i < tofind.size(); i++) {
 		tofind[i]->updateResult(true);
 	}
-	#if defined(__unix__) || defined(__APPLE__)
-		// Search for libraries in typical directories and in LD_LIBRARY_PATH
-		string gslibloc = GLEFindLibrary("libgs", &progress);
-		if (gslibloc != "") {
-			CmdLineArgString* gslib_stra = (CmdLineArgString*)tools->getOption(GLE_TOOL_GHOSTSCRIPT_LIB)->getArg(0);
-			gslib_stra->setValue(gslibloc.c_str());
-		}
+	// Search for libgs using dlopen/LoadLibrary
+	#ifdef __unix__
+	// unix must search for versioned libraries.  ghostscript package installs versioned libgs.so.10
+	// libgs-dev package installs the non versioned libgs.so
+	string name = "libgs.so";
+	string gslibloc = GLEFindLibrary(name, &progress,"gsapi_revision");
+	size_t version = 15;
+	while(gslibloc == "" && version > 8){
+		std::ostringstream toTry;
+		toTry << name << "." << version;
+		gslibloc = GLEFindLibrary(toTry.str(), &progress,"gsapi_revision");
+		version--;
+	}
 	#endif
+	#ifdef __APPLE__
+	string name = "libgs.dylib";
+	string gslibloc = GLEFindLibrary(name, &progress,"gsapi_revision");
+	#endif
+	#ifdef _WIN32
+	string name = "gsdll64.dll";
+	string gslibloc = GLEFindLibrary(name, &progress,"gsapi_revision");
+	#endif
+	// dlopen/LoadLibrary will only find it if it is installed properly.
+	// if it cannot be found this way then it is not install properly
+	// set to empty to warn the user - even if the initial search found it in a directory that
+	// it is not supposed to be in.
+	//if (gslibloc != "") {
+		CmdLineArgString* gslib_stra = (CmdLineArgString*)tools->getOption(GLE_TOOL_GHOSTSCRIPT_LIB)->getArg(0);
+		gslib_stra->setValue(gslibloc.c_str());
+	//}
 	output->println();
 	// Write installed GLE's to config section
 	ConfigSection* gle = collection->getSection(GLE_CONFIG_GLE);
@@ -637,21 +635,76 @@ bool try_load_config_sub(string& conf_name, vector<string>& triedLocations) {
 }
 
 bool do_load_config(const char* appname, char **argv, CmdLineObj& cmdline, ConfigCollection& coll) {
-	// Set GLE_TOP
-	// -> prefer environment var GLE_TOP
+	//
+	// -- loads the config file glerc from global location and user location
+	//
+	// -- Sets GLE_TOP if not set from environment or by searching for glerc
+	//    also sets GLE_BIN_DIR
+	//    GLE_TOP is location of global glerc, init.tex, and inittex.ini
+	//
+	//    GLE_TOP_DIR and GLE_BIN_DIR are program global variables
+	//
+	// -> prefer environment variable GLE_TOP
 	// -> otherwise, locate relative to executable location
+	//      Windows: search up one directory from the executable
+	//      C:\Program Files\gle\bin\gle.exe   << -- executable
+	//      C:\Program Files\gle\bin           << -- GLE_BIN_DIR
+	//      C:\Program Files\gle			   << -- GLE_TOP
+	//    Linux and macOS: search up one directory in share/gle-graphics or share/gle
+	//      /usr/local/bin/gle                 << -- executable
+	//      /usr/local/bin                     << -- GLE_BIN_DIR
+	//      /usr/local/share/gle-graphics      << -- GLE_TOP
+	//      /usr/local/share/gle               << -- GLE_TOP (deprecated)
+	//
 	string conf_name;
-	bool has_top = false;
-	bool has_config = false;
-	const char* top = getenv("GLE_TOP");
+	string exe_name;
+    bool has_top      = false;
+    bool has_config   = false;
+    bool has_exe_name = false;
+    // get from environment
+    const char* top = getenv("GLE_TOP");
+    if (top != NULL && top[0] != 0) {
+        has_top     = true;
+        GLE_TOP_DIR = top;
+    }
+    // get exe name and path
+	has_exe_name = GetExeName(appname, argv, exe_name);
+	if (has_exe_name) {
+		GetDirName(exe_name, GLE_BIN_DIR);
+		StripDirSep(GLE_BIN_DIR);
+	}
 	vector<string> triedLocations;
-	if (top == NULL || top[0] == 0) {
-		string exe_name;
-		bool has_exe_name = GetExeName(appname, argv, exe_name);
+	if (!has_top) {
+		// environment variable GLE_TOP not found
+		// search for GLE_TOP relative to exe_name
 		if (has_exe_name) {
-			GetDirName(exe_name, GLE_BIN_DIR);
-			StripDirSep(GLE_BIN_DIR);
+			// search for GLE_TOP - try to find glerc
+			GLE_TOP_DIR = GLE_BIN_DIR;
+			// Start one level higher than executable
+			StripPathComponents(&GLE_TOP_DIR, 1);
+			string save = GLE_TOP_DIR;
+			#if defined(__unix__) || defined(__APPLE__)
+				// FHS complaince first
+			   	// FHS Try one level higher than executable in share/gle-graphics
+				GLE_TOP_DIR += DIR_SEP + "share/gle-graphics";
+				has_config = try_load_config_sub(conf_name, triedLocations);
+				if(!has_config){
+					// try alternate location (deprecated)
+					GLE_TOP_DIR = save + DIR_SEP + "share/gle";
+					has_config = try_load_config_sub(conf_name, triedLocations);
+				}
+				if(!has_config){
+					// try one level up from executable for non FHS installations
+					GLE_TOP_DIR = save;
+					has_config = try_load_config_sub(conf_name, triedLocations);
+				}
+			#else // Windows
+			// search one level up
+			has_config = try_load_config_sub(conf_name, triedLocations);
+			#endif
+			/*
 			#ifdef GLETOP_CD
+				// not sure what this is doing
 				// Try relative path
 				GLE_TOP_DIR = GLEAddRelPath(exe_name, GLETOP_CD+1, GLETOP_REL);
 				has_config = try_load_config_sub(conf_name, triedLocations);
@@ -666,16 +719,13 @@ bool do_load_config(const char* appname, char **argv, CmdLineObj& cmdline, Confi
 					has_config = try_load_config_sub(conf_name, triedLocations);
 				}
 			#else
-				GLE_TOP_DIR = exe_name;
-				StripPathComponents(&GLE_TOP_DIR, 2);
 			#endif
+			*/
 		} else {
+			// cannot find exe so cannot search for GLE_TOP
 			// The user will see as error message: "$GLE_TOP/some_file" not found.
 			GLE_TOP_DIR = "$GLE_TOP";
 		}
-	} else {
-		has_top = true;
-		GLE_TOP_DIR = top;
 	}
 	StripDirSep(GLE_TOP_DIR);
 	if (!has_config) {
@@ -697,7 +747,7 @@ bool do_load_config(const char* appname, char **argv, CmdLineObj& cmdline, Confi
 	GLEInterface* iface = GLEGetInterfacePointer();
 	string uconf = iface->getUserConfigLocation();
 	if (uconf != "") {
-		// -> on Unix also $HOME/.glerc
+		// load user config
 		try_load_config(uconf);
 	}
 	// Set values for -v option
@@ -716,13 +766,24 @@ void do_find_deps_sub(GLEInterface* iface, const string& loc) {
 }
 
 void do_save_config() {
+	//
+	// -- saves config to users .glerc file
+	//
 	GLEInterface* iface = GLEGetInterfacePointer();
 	string conf_name = GLE_TOP_DIR + DIR_SEP + "glerc";
-	bool is_ok = try_save_config(conf_name, iface, false);
-	if (!is_ok) {
-		string user_conf = iface->getUserConfigLocation();
-		is_ok = try_save_config(user_conf, iface, true);
-	}
+	// should NOT save in global location - this is bad form.
+	// always save in user location
+	// only root can save in GLE_TOP/share/gle-graphics on linux
+	// only administrator can save in GLE_TOP on windows
+	// it is bad form to write in these locations for security reasons
+	// removed starting 4.3.9
+	//bool is_ok = try_save_config(conf_name, iface, false);
+	//if (!is_ok) {
+	//	string user_conf = iface->getUserConfigLocation();
+	//	is_ok = try_save_config(user_conf, iface, true);
+	//}
+	string user_conf = iface->getUserConfigLocation();
+	bool is_ok = try_save_config(user_conf, iface, true);
 	if (!is_ok) {
 		ostringstream err;
 		err << ">>> Can't write to config file '" << conf_name << "'" << endl;
