@@ -62,6 +62,7 @@
 #include "keyword.h"
 #include "run.h"
 #include "gle-poppler.h"
+#include "console_colors.h"
 
 using namespace std;
 
@@ -615,16 +616,10 @@ bool GLEInterface::hasCmdLineOptionString(const char* name) {
 string GLEInterface::getGhostScriptLocation() {
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
 #ifdef _WIN32
+	// gs DLL is in path next to ghostscript executable
 	string name = "gsdll32.dll";
-	#if _WIN64
-		// VS builds
-		name = "gsdll64.dll";	
-	#endif
-	#if __GNUC__
-		// gcc builds
-		#if __x86_64__ || __ppc64__
-			name = "gsdll64.dll";	
-		#endif
+	#if defined(_WIN64) || defined(__x86_64__) || defined(__ppc64__)
+		name = "gsdll64.dll";
 	#endif
 	string result = ((CmdLineArgString*)tools->getOptionValue(GLE_TOOL_GHOSTSCRIPT_CMD))->getValue();
 	if (IsAbsPath(result)) {
@@ -656,22 +651,62 @@ string GLEInterface::getUserConfigLocation() {
 	#if defined(__unix__) || defined(__APPLE__) || defined (__OS2__)
 		GLEGetEnv("HOME", location);
 	#endif
-	#ifdef _WIN32	
+	#ifdef _WIN32
 		GLEGetEnv("APPDATA", location);
 		if (location != "") {
 			AddDirSep(location);
-			location += "glx.sourceforge.net";
+			location += "gle-graphics";
 		}
+//		cout << "WIN32 getUserConfigLocation() "<<location<<endl;
 	#endif
 	if (location != "") {
 		AddDirSep(location);
 		location += ".glerc";
 	}
+//	cout << "getUserConfigLocation() "<<location<<endl;
 	return location;
 }
 
-string GLEInterface::getManualLocation() {
+string GLEInterface::getManualLocation()
+{
+	// used in GUI to find the manual.
+	// must account for different locations on different systems
+	//  windows:  GLE_TOP = C:\Program Files\gle
+	//     location is always GLE_TOP\doc
+	//  linux:    GLE_TOP = /usr/share/gle
+	//     location should be for FHS compliance
+	//     /usr/share/doc/gle          ==> GLE_TOP/../doc/gle
+	//     or
+	//     /usr/share/doc/gle-graphics ==> GLE_TOP/../doc/gle-graphics
+	//     but could also be subdir of GLE_TOP, which is not FHS complaint.
+	//     /usr/share/gle/doc          ==> GLE_TOP/doc
+	//     or
+	//     /usr/share/gle-graphics/doc ==> GLE_TOP/doc
 	string loc;
+	#if defined(__unix__) || defined(__APPLE__)
+		// try FHS location of GLE_TOP
+		if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 1, "doc/gle-graphics", "gle-manual.pdf", loc)) {
+			return loc;
+		}
+		if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 1, "doc/gle-graphics", "gle-manual.pdf.gz", loc)) {
+			return loc;
+		}
+		if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 1, "doc/gle", "gle-manual.pdf", loc)) {
+			return loc;
+		}
+		if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 1, "doc/gle", "gle-manual.pdf.gz", loc)) {
+			return loc;
+		}
+	#endif
+	// these should work on windows and all systems - subdir of GLE_TOP
+	if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 0, "doc", "gle-manual.pdf", loc)) {
+		return loc;
+	}
+	if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 0, "doc", "gle-manual.pdf.gz", loc)) {
+		return loc;
+	}
+	/*
+
 #ifdef GLEDOC_CD
 	if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, GLEDOC_CD, GLEDOC_REL, "gle-manual.pdf", loc)) {
 		return loc;
@@ -680,12 +715,7 @@ string GLEInterface::getManualLocation() {
 		return loc;
 	}
 #endif
-	if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 0, "doc", "gle-manual.pdf", loc)) {
-		return loc;
-	}
-	if (GLEAddRelPathAndFileTry(GLE_TOP_DIR, 0, "doc", "gle-manual.pdf.gz", loc)) {
-		return loc;
-	}
+
 #ifdef GLEDOC_ABS
 	if (GLEAddRelPathAndFileTry(GLEDOC_ABS, 0, NULL, "gle-manual.pdf", loc)) {
 		return loc;
@@ -694,6 +724,7 @@ string GLEInterface::getManualLocation() {
 		return loc;
 	}
 #endif
+*/
 	return loc;
 }
 
@@ -917,6 +948,7 @@ void GLEOutputStream::println() {
 
 void GLEOutputStream::println(const char* str) {
 	cerr << str << endl;
+	cerr << ConsoleColor::RESET;
 }
 
 void GLEOutputStream::printflush(const char* str) {
@@ -929,23 +961,20 @@ void GLEOutputStream::error(GLEErrorMessage* msg) {
 	const char* abbrev = msg->getLineAbbrev();
 	ostringstream output;
 	output << endl;
-	output << ">> " << file << " (" << msg->getLine() << ")";
+	output << ">> " << ColorInputFile(file) << " (" << ColorLineNumber(msg->getLine()) << ")";
 	if (abbrev[0] != 0) {
-		output << " |" << abbrev << "|";
+		output << " |" << ColorGLECode(abbrev) << "|" << endl;
 	}
 	if (msg->getColumn() != -1) {
 		char number[50];
-		output << endl;
-		output << ">> ";
+		output << ConsoleColor::BRIGHT_RED << ">> ";
 		sprintf(number, "%d", msg->getLine());
 		int nbspc = strlen(file) + strlen(number) + 4 + msg->getColumn() - msg->getDelta();
-		for (int i = 0; i < nbspc; i++) {
-			output << " ";
-		}
-		output << "^";
+		std::string spaces(nbspc, ' ');
+		output << spaces << "^" << ConsoleColor::RESET;
 	}
-	output << msg->getErrorMsg();
-	g_message(output.str().c_str());
+	//output << msg->getErrorMsg();
+	g_message(ColorErrorMessage(output.str()));
 }
 
 GLEDrawObject::GLEDrawObject() {
