@@ -38,6 +38,11 @@
 
 #define GLE_MAIN_CPP
 
+#include <set>
+#ifdef _WIN32
+	#include <io.h>
+#endif
+
 #include "all.h"
 #include "tokens/Tokenizer.h"
 #include "core.h"
@@ -50,12 +55,7 @@
 #include "drawit.h"
 #include "gle-interface/gle-interface.h"
 #include "gle-poppler.h"
-
-#ifdef _WIN32
-	#include <io.h>
-#endif
-
-#include <set>
+#include "console_colors.h"
 
 using namespace std;
 
@@ -170,7 +170,7 @@ int main(int argc, char **argv) {
 		if (g_CmdLine.getNbMainArgs() == 0 || g_CmdLine.hasOption(GLE_OPT_HELP)) {
 			string version;
 			g_get_version(&version);
-			cerr << "GLE version " << version << endl;
+			cerr << GLELogoColor << " version " << version << endl;
 			cerr << "Usage: gle [options] filename.gle" << endl;
 			cerr << "More information: gle " << g_CmdLine.getOptionPrefix() << "help" << endl;
 			if (g_CmdLine.hasOption(GLE_OPT_HELP)) {
@@ -255,7 +255,7 @@ void gle_cleanup() {
 
 void do_run_other_version(ConfigCollection& coll, int argc, char **argv) {
 	// Scan command line for -v option
-	// Note: can not use cmdline here because older versions might have different options
+	// Note: cannot use cmdline here because older versions might have different options
 	// which would result in an error message
 	string version = "";
 	for (int i = 1; i < argc-1; i++) {
@@ -291,15 +291,38 @@ void do_run_other_version(ConfigCollection& coll, int argc, char **argv) {
 }
 
 void do_show_info() {
-	string version, bdate;
+	string version, bdate, usrlib;
 	g_get_version(&version);
 	g_get_build_date(&bdate);
-	cout << "GLE version:             " << version << endl;
+	GLEInterface* iface = GLEGetInterfacePointer();
+	cout << GLELogoColor <<" version:             " << version << endl;
 	if (!bdate.empty()) {
 		cout << "Build date:              " << bdate << endl;
 	}
 	cout << "GLE_TOP:                 " << GLE_TOP_DIR << endl;
-	cout << "GLE_BIN:                 " << GLE_BIN_DIR << endl;
+	cout << "GLE_BIN_DIR:             " << GLE_BIN_DIR << endl;
+	const char* pusr_lib = getenv("GLE_USRLIB");
+	if (pusr_lib != NULL) {
+		usrlib = getenv("GLE_USRLIB");
+	}
+	cout << "GLE_USRLIB:              " << usrlib << endl;
+	// test for existence for these files
+	const string not_found_red = " \033[91m NOT FOUND\033[0m";
+	string fname = GLE_TOP_DIR+DIR_SEP+"glerc";
+	string exists = "";
+	if(!GLEFileExists(fname)) exists = not_found_red;
+	cout << "GLERC (global):          " << fname << exists << endl;
+
+	fname = iface->getUserConfigLocation();
+	exists = "";
+	if(!GLEFileExists(fname)) exists = not_found_red;
+	cout << "GLERC (user):            " << fname << exists << endl;
+
+	fname = GLE_TOP_DIR+DIR_SEP+"inittex.ini";
+	exists = "";
+	if(!GLEFileExists(fname)) exists = not_found_red;
+	cout << "inittex.ini:             " << fname << exists << endl;
+
 	/* Location of GhostScript */
 	string gs_dir;
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
@@ -934,7 +957,7 @@ bool GLELoadOneFileManager::process_one_file_tex() {
 
 void GLELoadOneFileManager::do_output_type(const char* type) {
 	if (g_verbosity() > 0) {
-		cerr << "[" << type << "]";
+		cerr << "[" << ColorOutputFile(type) << "]";
 		g_set_console_output(false);
 	}
 }
