@@ -1146,24 +1146,35 @@ bool create_bitmap_file_ghostscript(GLEFileLocation* fname, int device, int dpi,
 		return run_ghostscript(gsargs.str(), outputfile, !fname->isStdout(), &postscript);
 	}
 }
-// poppler bitmap creation not working on win32 CPP library - need to fix
-// in the meantime use gs for windows always
 bool create_bitmap_file(GLEFileLocation* fname, int device, int dpi, int options, GLEScript* script) {
-#if defined (HAVE_POPPLER) && ( defined(__unix__) || defined(__APPLE__) )
+#ifdef HAVE_POPPLER
+	//#ifdef BITMAP_CREATION_POPPLER
+	//cout << "creating bitmap poppler 1"<<endl;
 	bool supportsBitmapType = g_bitmap_supports_type(g_device_to_bitmap_type(device));
+	//cout << "creating bitmap poppler supported "<<supportsBitmapType<<endl;
 	string* bytesPDF = script->getRecordedBytesBuffer(GLE_DEVICE_PDF);
+	//cout << "creating bitmap poppler PDF "<<bytesPDF->empty()<<endl;
+	string* bytesEPS = script->getRecordedBytesBuffer(GLE_DEVICE_EPS);
+	//cout << "creating bitmap poppler EPS"<<bytesEPS->empty()<<endl;
 	if (supportsBitmapType && !bytesPDF->empty()) {
+		//cout << "creating bitmap poppler 2"<<endl;
 		std::string myFName = fname->getFullPath();
 		myFName += g_device_to_ext(device);
 		if (g_verbosity() >= 5) {
 			g_message(std::string("[Poppler PDF conversion: ") + myFName + "]");
 		}
+		//g_message(std::string("[Poppler PDF conversion: ") + myFName + "]");
 		gle_convert_pdf_to_image_file((char*)bytesPDF->c_str(), (int)bytesPDF->size(), dpi, device, options, myFName.c_str());
 		return true;
+	}else{
+		//cout << "creating bitmap poppler - ghostscript"<<endl;
+		return create_bitmap_file_ghostscript(fname, device, dpi, options, script);
 	}
-#else
+	return false;
+#else // BITMAP_CREATION_GHOSTSCRIPT
+	//cout << "creating bitmap gs"<<endl;
 	return create_bitmap_file_ghostscript(fname, device, dpi, options, script);
-#endif // HAVE_POPPLER
+#endif // BITMAP_CREATION_POPPLER
 }
 
 bool create_pdf_file_ghostscript(GLEFileLocation* fname, int dpi, GLEScript* script) {
@@ -1303,11 +1314,13 @@ bool create_pdf_file_pdflatex(const string& fname, GLEScript* script) {
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
 	string cmdline(get_tool_path(GLE_TOOL_PDFTEX_CMD, tools));
 	str_try_add_quote(cmdline);
+	/* options unused
 	const string pdftex_opts(tools->getOptionString(GLE_TOOL_PDFTEX_OPTIONS));
 	if (!pdftex_opts.empty()) {
 		cmdline += " ";
 		cmdline += pdftex_opts;
 	}
+	*/
 	cmdline += string(" \"") + file + ".tex\"";
 	string outfile = file + ".pdf";
 	if (g_verbosity() >= 5) {
@@ -1344,11 +1357,14 @@ bool run_latex(const string& dir, const string& file) {
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
 	string cmdline(get_tool_path(GLE_TOOL_LATEX_CMD, tools));
 	str_try_add_quote(cmdline);
+	/*
+	options unused
 	const string latex_opts(tools->getOptionString(GLE_TOOL_LATEX_OPTIONS));
 	if (!latex_opts.empty()) {
 		cmdline += " ";
 		cmdline += latex_opts;
 	}
+	*/
 	cmdline += string(" \"") + file + ".tex\"";
 	string outfile = file + ".dvi";
 	if (g_verbosity() >= 5) {
@@ -1421,11 +1437,14 @@ bool run_ghostscript(const string& args, const string& outfile, bool redirout, i
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
 	string cmdline(get_tool_path(GLE_TOOL_GHOSTSCRIPT_CMD, tools));
 	str_try_add_quote(cmdline);
+	/*
+	options unused
 	const string gs_opts(tools->getOptionString(GLE_TOOL_GHOSTSCRIPT_OPTIONS));
 	if (!gs_opts.empty()) {
 		cmdline += " ";
 		cmdline += gs_opts;
 	}
+	*/
 	cmdline += " ";
 	cmdline += args;
 	if (g_verbosity() >= 5) {
@@ -1478,8 +1497,10 @@ bool run_dvips(const string& file, bool eps) {
 		// construct dvips arguments
 		ostringstream dvipsargs;
 		dvipsargs << dvips_cmd;
+		/* options unused
 		const string dvips_opts(tools->getOptionString(GLE_TOOL_DVIPS_OPTIONS));
 		if (!dvips_opts.empty()) dvipsargs << " " << dvips_opts;
+		*/
 		if (eps) dvipsargs << " -E";
 		const string outfile(file + (eps ? ".eps" : ".ps"));
 		dvipsargs << " -o \"" << outfile << "\" \"" << file << ".dvi\"";
