@@ -19,7 +19,11 @@
  * Also add information on how to contact you by electronic and paper mail.        *
  ***********************************************************************************/
 
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 #include <QtGui>
+#include <QFileInfo>
+#include <filesystem>
 #include "qgle_statics.h"
 #include "qgle_definitions.h"
 #include "drawingobject.h"
@@ -48,14 +52,19 @@ QString QGLE::prettyDate(QString datestr)
 	// provided date
 	QDate dt = QDate::fromString(datestr, "dd/MM/yyyy");
 	QString prettyString = dt.toString("d MMMM yyyy");
-	QRegExp rx("^(\\d?)(\\d)(?= )");
+	//QRegExp rx("^(\\d?)(\\d)(?= )");
+	QRegularExpression rx("^(\\d?)(\\d)(?= )");
 	QString suffix;
-	if(rx.indexIn(prettyString) > -1)
+	//if(rx.indexIn(prettyString) > -1)
+	QRegularExpressionMatch match = rx.match(prettyString);
+	if(match.hasMatch())
 	{
-		if (rx.capturedTexts()[1].toInt() == 1)
+		//if (rx.capturedTexts()[1].toInt() == 1)
+		if (match.captured(1).toInt() == 1)
 			suffix = "th";
 		else
-			switch(rx.capturedTexts()[2].toInt())
+			//switch(rx.capturedTexts()[2].toInt())
+		    switch(match.captured(2).toInt())
 			{
 				case 1:
 					suffix = "st";
@@ -69,7 +78,8 @@ QString QGLE::prettyDate(QString datestr)
 				default:
 					suffix = "th";
 			}
-		prettyString.replace(rx, rx.capturedTexts()[0] + suffix);
+		//prettyString.replace(rx, rx.capturedTexts()[0] + suffix);
+		prettyString.replace(rx, match.captured(0) + suffix);
 	}
 	return(prettyString);
 
@@ -378,17 +388,19 @@ int QGLE::computeAutoScaleDPIFromPts(const QSize& bitmapSize, int inset, double
 
 QString QGLE::GetExeName()
 {
-	QString result = QString::null;
+	// QString result = QString::null;
+	QString result;
 #ifdef Q_OS_WIN32
 	char name[1024];
 	DWORD res = GetModuleFileNameA(NULL, name, 1023);
 	if (res > 0)
 	{
-		name[res] = 0;
+		//name[res] = 0;
 		result = name;
 	}
 #elif defined(Q_OS_HURD) || defined Q_OS_LINUX
-	return(QFileInfo("/proc/self/exe").readLink());
+	//return(QFileInfo("/proc/self/exe").readLink());
+	return(QFileInfo("/proc/self/exe").symLinkTarget());
 #else
 	return(QApplication::applicationFilePath());
 #endif
@@ -415,17 +427,30 @@ QString QGLE::GetDirName(QString fname)
 	// return(fi.absolutePath());
 }
 
-QRegExp QGLE::fileRegExp()
+// old qt5
+// QRegExp QGLE::fileRegExp()
+// {
+// #ifdef Q_OS_WIN32
+// 	QRegExp rx("(file:///)?(.*\\.(?:gle|eps))", Qt::CaseInsensitive);
+// #else
+// //#elif defined(Q_OS_HURD) || defined(Q_OS_LINUX)
+// 	QRegExp rx("(file://)?(.*\\.(?:gle|eps))", Qt::CaseInsensitive);
+// #endif
+// 	return(rx);
+// }
+
+
+QRegularExpression QGLE::fileRegExp()
 {
 #ifdef Q_OS_WIN32
-	QRegExp rx("(file:///)?(.*\\.(?:gle|eps))", Qt::CaseInsensitive);
+    QRegularExpression rx("(file:///)?(.*\\.(?:gle|eps))", QRegularExpression::CaseInsensitiveOption);
 #else
-//#elif defined(Q_OS_HURD) || defined(Q_OS_LINUX)
-	QRegExp rx("(file://)?(.*\\.(?:gle|eps))", Qt::CaseInsensitive);
+    QRegularExpression rx("(file://)?(.*\\.(?:gle|eps))", QRegularExpression::CaseInsensitiveOption);
 #endif
-	return(rx);
+    return rx;
 }
 
+
 QString QGLE::gsLibFileName()
 {
 #ifdef Q_OS_WIN32
@@ -868,10 +893,15 @@ QString QGLE::addFileNameExtension(const QString& name, const char* ext)
 }
 
 void QGLE::ensureFileNameExtension(QString* str, const char* ext) {
-	QRegExp rxExt(QString(".*\\.") + ext);
-	rxExt.setCaseSensitivity(Qt::CaseInsensitive);
-	if (!rxExt.exactMatch(*str)) {
-		*str += ".";
-		*str += ext;
+	//QRegExp rxExt(QString(".*\\.") + ext);
+	//rxExt.setCaseSensitivity(Qt::CaseInsensitive);
+	//if (!rxExt.exactMatch(*str)) {
+	//	*str += ".";
+	//	*str += ext;
+	//}
+	QRegularExpression rxExt(".*\\." + QRegularExpression::escape(ext), QRegularExpression::CaseInsensitiveOption);
+	if (!rxExt.match(*str).hasMatch()) {
+    	*str += ".";
+    	*str += ext;
 	}
 }
